summaryrefslogtreecommitdiffstats
path: root/sbin/quotacheck
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
committertrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
commit136be46680c6e4a18cc827da991d4f9a0de29cba (patch)
treeb5ee0aba66633a4e0e47097e4f383c253a87887a /sbin/quotacheck
parent9618da3e35435c433d8086d65af15f716ffe32ec (diff)
downloadFreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.zip
FreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.tar.gz
s/filesystem/file system/g as discussed on -developers
Diffstat (limited to 'sbin/quotacheck')
-rw-r--r--sbin/quotacheck/preen.c2
-rw-r--r--sbin/quotacheck/quotacheck.828
-rw-r--r--sbin/quotacheck/quotacheck.c6
3 files changed, 18 insertions, 18 deletions
diff --git a/sbin/quotacheck/preen.c b/sbin/quotacheck/preen.c
index a049a56..4571f67 100644
--- a/sbin/quotacheck/preen.c
+++ b/sbin/quotacheck/preen.c
@@ -60,7 +60,7 @@ char *blockcheck(char *origname);
struct part {
struct part *next; /* forward link of partitions on disk */
char *name; /* device name */
- char *fsname; /* mounted filesystem name */
+ char *fsname; /* mounted file system name */
long auxdata; /* auxiliary data for application */
} *badlist, **badnext = &badlist;
diff --git a/sbin/quotacheck/quotacheck.8 b/sbin/quotacheck/quotacheck.8
index 069db3c..fb544a1 100644
--- a/sbin/quotacheck/quotacheck.8
+++ b/sbin/quotacheck/quotacheck.8
@@ -40,13 +40,13 @@
.Os
.Sh NAME
.Nm quotacheck
-.Nd filesystem quota consistency checker
+.Nd file system quota consistency checker
.Sh SYNOPSIS
.Nm
.Op Fl g
.Op Fl u
.Op Fl v
-.Ar filesystem
+.Ar file system
.Ar
.Nm
.Op Fl g
@@ -56,22 +56,22 @@
.Sh DESCRIPTION
The
.Nm
-utility examines each filesystem,
+utility examines each file system,
builds a table of current disk usage,
and compares this table against that recorded
-in the disk quota file for the filesystem.
+in the disk quota file for the file system.
If any inconsistencies are detected, both the
quota file and the current system copy of the
incorrect quotas are updated (the latter only
-occurs if an active filesystem is checked).
+occurs if an active file system is checked).
By default both user and group quotas are checked.
.Pp
The following options are available:
.Bl -tag -width indent
.It Fl a
-If supplied in place of any filesystem names,
+If supplied in place of any file system names,
.Nm
-will check all the filesystems indicated in
+will check all the file systems indicated in
.Pa /etc/fstab
to be read-write with disk quotas.
By default only the types of quotas listed in
@@ -95,7 +95,7 @@ Specifying both
and
.Fl u
is equivalent to the default.
-Parallel passes are run on the filesystems required,
+Parallel passes are run on the file systems required,
using the pass numbers in
.Pa /etc/fstab
in an identical fashion to
@@ -107,12 +107,12 @@ operates silently.
.Pp
The
.Nm
-utility expects each filesystem to be checked to have a
+utility expects each file system to be checked to have a
quota files named
.Pa quota.user
and
.Pa quota.group
-which are located at the root of the associated filesystem.
+which are located at the root of the associated file system.
These defaults may be overridden in
.Pa /etc/fstab .
If a file is not present,
@@ -143,18 +143,18 @@ The
.Nm
utility accesses the raw device in calculating the actual
disk usage for each user.
-Thus, the filesystems
+Thus, the file systems
checked should be quiescent while
.Nm
is running.
.Sh FILES
.Bl -tag -width quota.group -compact
.It Pa quota.user
-at the filesystem root with user quotas
+at the file system root with user quotas
.It Pa quota.group
-at the filesystem root with group quotas
+at the file system root with group quotas
.It Pa /etc/fstab
-default filesystems
+default file systems
.El
.Sh SEE ALSO
.Xr quota 1 ,
diff --git a/sbin/quotacheck/quotacheck.c b/sbin/quotacheck/quotacheck.c
index 8407676..a8c051b 100644
--- a/sbin/quotacheck/quotacheck.c
+++ b/sbin/quotacheck/quotacheck.c
@@ -109,7 +109,7 @@ struct fileusage {
#define FUHASH 1024 /* must be power of two */
struct fileusage *fuhead[MAXQUOTAS][FUHASH];
-int aflag; /* all filesystems */
+int aflag; /* all file systems */
int gflag; /* check group quotas */
int uflag; /* check user quotas */
int vflag; /* verbose */
@@ -254,7 +254,7 @@ needchk(fs)
static int sblock_try[] = SBLOCKSEARCH;
/*
* Scan the specified filesystem to check quota(s) present on it.
*/
int
chkquota(fsname, mntpt, qnp)
@@ -292,7 +292,7 @@ chkquota(fsname, mntpt, qnp)
break;
}
if (sblock_try[i] == -1) {
- warn("Cannot find filesystem superblock");
+ warn("Cannot find file system superblock");
return (1);
}
dev_bsize = sblock.fs_fsize / fsbtodb(&sblock, 1);
@@ -254,7 +254,7 @@ needchk(fs)
static int sblock_try[] = SBLOCKSEARCH;
/*
- * Scan the specified filesystem to check quota(s) present on it.
+ * Scan the specified file system to check quota(s) present on it.
*/
int
OpenPOWER on IntegriCloud